@@ -96,7 +96,7 @@ def rename(
     if new_name:
         if with_suffix or with_prefix:
             raise ValueError(
-                "You don't need to do that, considering this"
+                "You don't need to do that, considering in this"
                 " way: 'prefix-newname.suffix'"
             )
         suffix = Path(path).ext
